local AddonName, a = ...
if a.BuildFail(50000) then return end
local L = a.Localize
local s = SpellFlashAddon
local x = s.UpdatedVariables

-- SpellFlash API:
-- http://wow.curseforge.com/addons/spellflash/pages/api/

-- Updated variable references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-local-x-spell-flash-addon-updated-variables
-- x.Enemy, x.ActiveEnemy, x.NoCC, x.InInstance, x.InstanceType, x.PetAlive, x.PetActiveEnemy, x.PetNoCC, x.Lag, x.DoubleLag, x.ThreatPercent, x.EnemyDetected, x.ShouldPermanentBuff, x.ShouldTemporaryBuff

-- Spell table references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-s-castable

local StatBuffs = {
	1126--[[Mark of the Wild]],
	115921--[[Legacy of the Emperor]],
	20217--[[Blessing of Kings]],
}

function keepupShuffle()
	remainingShuffleDuration = s.MyBuffDuration(115307--[[Shuffle]], "player")
	remainingKegSmashCD, _ = s.SpellCooldown(121253--[[Keg Smash]])
	if (remainingKegSmashCD + 2 ) < remainingShuffleDuration then
		return true
	end
	if ((s.Power("player", 12) - 2) >= 2) and remainingShuffleDuration > 1 then
		return true
	end
	if ((s.Power("player", 12) - 2) == 1) and remainingShuffleDuration > 2 then
		return true
	end
	if ((s.Power("player", 12) - 2) == 0) and remainingShuffleDuration > 3 then
		return true
	end
	return false
end

function powerCap()
	remainingEBCD, _ = s.SpellCooldown(115288--[[Energizing Brew]])
	remainingFoFCD, _ = s.SpellCooldown(113656--[[Fists of Fury]])
	if remainingEBCD == 0 then
		return 40
	end
	if remainingFoFCD == 0 then
		return 60
	end
	return 80
end

a.spells["Auto Attack"] = {
	ID = 6603--[[Auto Attack]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	NotIfActive = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC
	end,
}

a.spells["Purify Moderate Stagger"] = {
	ID = 119582--[[Purifying Brew]],
	NoGCD = 1,
	FlashColor = "Yellow",
	RequireDebuff = 124274--[[Moderate Stagger]],
	RequireBuffUnit = "player", 
}

a.spells["Purify Heavy Stagger"] = {
	ID = 119582--[[Purifying Brew]],
	NoGCD = 1,
	FlashColor = "Red",
	RequireDebuff = 124273--[[Heavy Stagger]],
	RequireBuffUnit = "player", 
}

a.spells["Blackout Kick (Brewmaster)"] = {
	ID = 100784--[[Blackout Kick]],
	Buff = 115307--[[Shuffle]],
	BuffUnit = "player",
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		return x.NoCC
	end,
}

a.spells["Zen Sphere (Brewmaster)"] = {
	ID = 124081--[[Zen Sphere]],
	MyBuff = 124081--[[Zen Sphere]],
	BuffUnit = "player",
	NoRangeCheck = 1,
	Unit = "player",
	EarlyRefresh = 1,
	CheckFirst = function(z)
		return keepupShuffle()
	end,
}

a.spells["Zen Sphere (Windwalker)"] = {
	ID = 124081--[[Zen Sphere]],
	MyBuff = 124081--[[Zen Sphere]],
	BuffUnit = "player",
	NoRangeCheck = 1,
	Unit = "player",
	EarlyRefresh = 1,
	CheckFirst = function(z)
		return s.InCombat() and not s.Channeling(113656--[[Fists of Fury]], "player")
	end,
}

a.spells["Breath of Fire"] = {
	ID = 115181--[[Breath of Fire]],
	MyDebuff = 115181--[[Breath of Fire]],
	RequireDebuff = 115180--[[Dizzying Haze]],
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		return x.NoCC and keepupShuffle()
	end,
}

a.spells["Rising Sun Kick (Debuff)"] = {
	ID = 107428--[[Rising Sun Kick]],
	MyDebuff = 107428--[[Rising Sun Kick]],
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		return x.NoCC and not s.Channeling(113656--[[Fists of Fury]], "player")
	end,
}

a.spells["Rising Sun Kick"] = {
	ID = 107428--[[Rising Sun Kick]],
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		return x.NoCC and not s.Channeling(113656--[[Fists of Fury]], "player")
	end,
}

a.spells["Fists of Fury"] = {
	ID = 113656--[[Fists of Fury]],
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		return x.NoCC
	end,
}

a.spells["Energizing Brew"] = {
	ID = 115288--[[Energizing Brew]],
	CheckFirst = function(z)
		return s.InCombat() and not s.Channeling(113656--[[Fists of Fury]], "player")
	end,
}

a.spells["Spinning Crane Kick (Brewmaster)"] = {
	ID = 101546--[[Spinning Crane Kick]],
	FlashColor = "Purple",
	CheckFirst = function(z)
		return (s.MyBuffDuration(115307--[[Shuffle]], "player") > 4 and s.Power("player", 12) == 0) or (s.MyBuffDuration(115307--[[Shuffle]], "player") > 3 and s.Power("player", 12) > 0)
	end,
	Continue = 1,
}
a.spells["Keg Smash"] = {
	ID = 121253--[[Keg Smash]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	CheckFirst = function(z)
		return x.NoCC and (s.Power("player", 12) <= s.MaxPower("player", 12) - 2)
	end,
}

a.spells["Expel Harm (Brewmaster)"] = {
	ID = 115072--[[Expel Harm]],
	CheckFirst = function(z)
		return s.HealthPercent("player") < 80
	end,
}

a.spells["Expel Harm (close to cap)"] = {
	ID = 115072--[[Expel Harm]],
	CheckFirst = function(z)
		return s.HealthPercent("player") < 80 and s.Power("player", 3) > powerCap() and not s.Channeling(113656--[[Fists of Fury]], "player")
	end,
	FlashColor = "Pink",
	Continue = 1,
}

a.spells["Expel Harm (no Chi)"] = {
	ID = 115072--[[Expel Harm]],
	CheckFirst = function(z)
		return s.HealthPercent("player") < 80 and s.Power("player", 12) == 0 and not s.Channeling(113656--[[Fists of Fury]], "player")
	end,
	FlashColor = "Pink",
	Continue = 1,
}

a.spells["Flying Serpent Kick"] = {
	ID = 101545--[[Flying Serpent Kick]],
	CheckFirst = function(z)
		return s.Power("player", 3) < 30 and s.InCombat() and not s.Channeling(113656--[[Fists of Fury]], "player")
	end,
	FlashColor = "Pink",
}

a.spells["Jab (Brewmaster)"] = {
	ID = 100780--[[Jab]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	CheckFirst = function(z)
		return x.NoCC and (s.Power("player", 12) <= s.MaxPower("player", 12) - 1)
	end,
}

a.spells["Jab (close to cap)"] = {
	ID = 100780--[[Jab]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	CheckFirst = function(z)
		return x.NoCC and s.Power("player", 3) > powerCap() and not s.Channeling(113656--[[Fists of Fury]], "player")
	end,
}

a.spells["Jab (no Chi)"] = {
	ID = 100780--[[Jab]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	CheckFirst = function(z)
		return x.NoCC and s.Power("player", 12) == 0 and not s.Channeling(113656--[[Fists of Fury]], "player")
	end,
}

a.spells["Guard"] = {
	ID = 115295--[[Guard]],
	NoGCD = 1,
	FlashColor = "Yellow",
	CheckFirst = function(z)
		return s.HealthPercent("player") < 75 and s.InCombat()
	end,
}

a.spells["Tiger Palm (Brewmaster)"] = {
	ID = 100787--[[Tiger Palm]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	CheckFirst = function(z)
		return x.NoCC and s.MyBuffDuration(115307--[[Shuffle]], "player") > 1
	end,
}

a.spells["Combo Breaker: Tiger Palm"] = {
	ID = 100787--[[Tiger Palm]],
	RequireBuff =  118864--[[Combo Breaker: Tiger Palm]],
	RequireBuffUnit = "player",
	EnemyTargetNeeded = 1,
	Melee = 1,
	CheckFirst = function(z)
		return x.NoCC and not s.Channeling(113656--[[Fists of Fury]], "player")
	end,
}

a.spells["Combo Breaker: Blackout Kick"] = {
	ID = 100784--[[Blackout Kick]],
	RequireBuff =  116768--[[Combo Breaker: Blackout Kick]],
	RequireBuffUnit = "player",
	EnemyTargetNeeded = 1,
	Melee = 1,
	CheckFirst = function(z)
		return x.NoCC and not s.Channeling(113656--[[Fists of Fury]], "player")
	end,
}

a.spells["Blackout Kick (Windwalker)"] = {
	ID = 100784--[[Blackout Kick]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	CheckFirst = function(z)
		return x.NoCC and not s.Channeling(113656--[[Fists of Fury]], "player")
	end,
}

a.spells["Tigereye Brew"] = {
	ID = 116740--[[Tigereye Brew]],
	RequireBuff = 125195--[[Tigereye Brew]],
	RequireBuffUnit = "player",
	RequireStack = 10,
	CheckFirst = function(z)
		return x.NoCC and s.InCombat() and not s.Channeling(113656--[[Fists of Fury]], "player")
	end,
}

a.spells["Tiger Palm (Buff)"] = {
	ID = 100787--[[Tiger Palm]],
	Buff = 125359--[[Tiger Power]],
	BuffUnit = "player",
	Stack = 3,
	EarlyRefresh = 2,
	EnemyTargetNeeded = 1,
	Melee = 1,
	CheckFirst = function(z)
		return x.NoCC and not s.Channeling(113656--[[Fists of Fury]], "player")
	end,
}

a.spells["Elusive Brew"] = {
	ID = 115308--[[Elusive Brew]],
	FlashColor = "Yellow",
	CheckFirst = function(z)
		return s.MyBuffStack(115308--[[Elusive Brew]], "player") >= 3 and s.InCombat()
	end,
	NoGCD = 1,
}

a.spells["Fortifying Brew"] = {
	ID = 115203--[[Fortifying Brew]],
	FlashColor = "Red",
	CheckFirst = function(z)
		return s.HealthPercent("player") < 50 and s.InCombat()
	end,
	NoGCD = 1,
}

a.spells["Legacy of the Emperor"] = {
	ID = 115921--[[Legacy of the Emperor]],
	Buff = StatBuffs,
	BuffUnit = "all",
	FlashColor = "Green",
}

a.spells["Spear Hand Strike"] = {
	ID = 116705--[[Spear Hand Strike]],
	EnemyTargetNeeded = 1,
	Interrupt = 1,
	NoGCD = 1,
	FlashColor = "Aqua",
}

a.spells["Paralysis"] = {
	ID = 115078--[[Paralysis]],
	EnemyTargetNeeded = 1,
	Interrupt = 1,
	CheckFirst = function(z)
		return not s.Boss("target")
	end,
	FlashColor = "Aqua",
}

a.spells["Leg Sweep"] = {
	ID = 119381--[[Leg Sweep]],
	EnemyTargetNeeded = 1,
	Interrupt = 1,
	CheckFirst = function(z)
		return not s.Boss("target")
	end,
	FlashColor = "Aqua",
}

a.spells["Provoke"] = {
	ID = 115546--[[Provoke]],
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		return s.Form(115069--[[Stance of the Sturdy Ox]]) and x.NoCC and x.ThreatPercent <= 99 and ( GetNumGroupMembers() > 1 or GetNumSubgroupMembers() > 0 ) and s.InCombat()
	end,
	NoGCD = 1,
	FlashColor = "Purple",
}

a.spells["Clash"] = {
	ID = 122057--[[Clash]],
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		return x.NoCC and not s.MeleeDistance("target")
	end,
	NoGCD = 1,
	FlashColor = "Yellow",
}

a.spells["Roll"] = {
	ID = 109132--[[Roll]],
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		return x.NoCC and not s.MeleeDistance("target")
	end,
	NoGCD = 1,
	FlashColor = "Yellow",
}

a.spells["Dizzying Haze"] = {
	ID = 115180--[[Dizzying Haze]],
	Debuff = 115180--[[Dizzying Haze]],
	EnemyTargetNeeded = 1,
	NoRangeCheck = 1,
	FlashColor = "Blue",
	Continue = 1,
}